summaryrefslogtreecommitdiffstats
path: root/ksystemlog/src/logListItem.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'ksystemlog/src/logListItem.cpp')
-rw-r--r--ksystemlog/src/logListItem.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/ksystemlog/src/logListItem.cpp b/ksystemlog/src/logListItem.cpp
index ebbed6b..34c7c38 100644
--- a/ksystemlog/src/logListItem.cpp
+++ b/ksystemlog/src/logListItem.cpp
@@ -52,8 +52,8 @@ LogListItem::LogListItem(TQListView* list, LogLine* l) :
}
-LogListItem::LogListItem(TQListViewItem* tqparent, LogLine* l) :
- KListViewItem(tqparent),
+LogListItem::LogListItem(TQListViewItem* parent, LogLine* l) :
+ KListViewItem(parent),
line(l)
{
@@ -185,7 +185,7 @@ void LogListItem::paintCell(TQPainter* p, const TQColorGroup& cg, int column, in
if (line->isParentLogLine()==true && column==0) {
//Draw 3 gray lines around the tqparent item
pBuf.setPen(cg.button());
pBuf.drawLine(0, 0, width, 0);
pBuf.drawLine(0, height()-1, width, height()-1);
@@ -200,7 +200,7 @@ void LogListItem::paintCell(TQPainter* p, const TQColorGroup& cg, int column, in
//Draw the item name in bold if it is a recent one
if (line->isRecent()==true && column==lv->columns()-1)
font.setBold(true);
//Draw in italic and bold if it's a tqparent item
else if (line->isParentLogLine()==true && column==0) {
font.setItalic(true);
font.setBold(true);
@@ -227,7 +227,7 @@ void LogListItem::paintCell(TQPainter* p, const TQColorGroup& cg, int column, in
text_x=1;
//If this is the first column and also a tqparent log line
if (line->isParentLogLine()==true && column==0) {
if (KSystemLogConfig::colorizeLogLines() && ((ParentLogLine*)line)->getGroupBy()==GROUP_BY_LOG_LEVEL)
pBuf.setPen( isSelected() ? cg.text() : line->getLogLevel()->color);
@@ -185,7 +185,7 @@ void LogListItem::paintCell(TQPainter* p, const TQColorGroup& cg, int column, in
if (line->isParentLogLine()==true && column==0) {
- //Draw 3 gray lines around the tqparent item
+ //Draw 3 gray lines around the parent item
pBuf.setPen(cg.button());
pBuf.drawLine(0, 0, width, 0);
@@ -200,7 +200,7 @@ void LogListItem::paintCell(TQPainter* p, const TQColorGroup& cg, int column, in
if (line->isRecent()==true && column==lv->columns()-1)
font.setBold(true);
- //Draw in italic and bold if it's a tqparent item
+ //Draw in italic and bold if it's a parent item
else if (line->isParentLogLine()==true && column==0) {
font.setItalic(true);
@@ -227,7 +227,7 @@ void LogListItem::paintCell(TQPainter* p, const TQColorGroup& cg, int column, in
text_x=1;
- //If this is the first column and also a tqparent log line
+ //If this is the first column and also a parent log line
if (line->isParentLogLine()==true && column==0) {
if (KSystemLogConfig::colorizeLogLines() && ((ParentLogLine*)line)->getGroupBy()==GROUP_BY_LOG_LEVEL)